@@ -11,7 +11,7 @@ import time
 import datetime
 
 
-from logtools.filelog import LogFile
+from basic_logtools.filelog import LogFile
 
 from networktools.time import timestamp
 from networktools.library import my_random_string
