@@ -11,7 +11,7 @@ import datetime
 
 from pathlib import Path
 import os
-from logtools.filelog import LogFile
+from basic_logtools.filelog import LogFile
 
 from networktools.time import timestamp, now
 from networktools.library import my_random_string
